/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  SVR: Simple HTTP(S) Server

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
import TLS from 'node:tls';
/* *
 *
 *  Class
 *
 * */
export class Request {
    /* *
     *
     *  Constructor
     *
     * */
    constructor(server, input, output) {
        const protocol = (input.socket instanceof TLS.TLSSocket ? 'https' : 'http');
        this.input = output.req;
        this.output = output;
        this.protocol = protocol;
        this.server = server;
        this.url = new URL((input.url || ''), `${protocol}://${input.headers.host}`);
    }
    /* *
     *
     *  Functions
     *
     * */
    body() {
        if (this._body) {
            return Promise.resolve(this._body);
        }
        return new Promise((resolve, reject) => {
            const input = this.input;
            const chunks = [];
            input.on('error', reject);
            input.on('data', (chunk) => chunks.push(chunk));
            input.on('end', () => {
                this._body = Buffer.concat(chunks);
                resolve(this._body);
            });
        });
    }
}
/* *
 *
 *  Default Export
 *
 * */
export default Request;
